@@ -147,7 +147,7 @@ def get_node(credentials, node, snapshot_source, snapshot):
         "source": parts[0],
         "path": path,
         "timestamp": int(time.time() * 1000),
-        "queryuser": "",
+        "queryuser": get_field_value(snapshot, 'testUser'),
         "checksum": hashlib.md5("{}".encode('utf-8')).hexdigest(),
         "node": node,
         "snapshotId": node['snapshotId'],
@@ -207,7 +207,7 @@ def get_all_nodes(credentials, node, snapshot_source, snapshot, snapshot_data):
         "source": parts[0],
         "path": "",
         "timestamp": int(time.time() * 1000),
-        "queryuser": "",
+        "queryuser": get_field_value(snapshot, 'testUser'),
         "checksum": hashlib.md5("{}".encode('utf-8')).hexdigest(),
         "node": node,
         "snapshotId": None,
